@@ -3,5 +3,8 @@
 // in the LICENSE file.
 
 pub mod arch;
-pub mod expand_env;
+pub mod env;
+pub mod fs;
+pub mod grp;
+pub mod pwd;
 pub mod str;
