@@ -7,17 +7,23 @@ pub mod core;
 pub mod arch;
 pub mod cp;
 pub mod error;
+pub mod groups;
 pub mod hashsum;
 pub mod head;
+pub mod id;
 pub mod ln;
 pub mod ls;
 pub mod mkdir;
 pub mod mv;
 pub mod nice;
+pub mod pwd;
 pub mod renice;
 pub mod rm;
 pub mod sleep;
 pub mod sync;
+pub mod touch;
+pub mod truncate;
 pub mod uname;
+pub mod unlink;
 pub mod uptime;
 pub mod whoami;
