@@ -4,7 +4,7 @@
 
 use glob::glob;
 
-use crate::core::expand_env::expand_env;
+use crate::core::env::expand_env;
 use crate::error::Error;
 
 #[derive(Debug, Default)]
